SystemOrganization addCategory: 'ConfigurationOfGrease'!

Object subclass: #ConfigurationOfGrease
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfGrease'!

!ConfigurationOfGrease class methodsFor: 'private' stamp: 'dkh 11/12/2009 09:11'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfGrease class methodsFor: 'private' stamp: 'dkh 12/01/2009 16:26'!
ensureMetacello
	"Minimum package versions from which to boot Metacello. Corresponds to version 1.0-beta.15"

	Smalltalk at: #MetacelloProject ifAbsent: [
		Smalltalk at: #Gofer ifAbsent: [
			"Minimum version of Gofer from which to bootstrap"
			self bootstrapPackage: 'Gofer-lr.83' from: 'http://seaside.gemstone.com/ss/metacello' ].
		Smalltalk at: #Gofer ifPresent: [:gofer |
			gofer new
				url: 'http://seaside.gemstone.com/ss/metacello';
				addVersion: 'Metacello-Core-dkh.302'; "Minimum version from which to bootstrap Metacello"
				addVersion: 'Metacello-MC-dkh.258'; "Minimum version from which to bootstrap Metacello"
				addPackage: 'ConfigurationOfMetacello'; "Loads latest version of configuration package"
				load ].
		"load latest version of Metacello, load a specific version if desired"
		(Smalltalk at: #ConfigurationOfMetacello) loadLatestVersion ]! !

!ConfigurationOfGrease class methodsFor: 'metacello tool support' stamp: 'dkh 11/12/2009 09:11'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfGrease class methodsFor: 'metacello tool support' stamp: 'dkh 11/13/2009 16:33'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfGrease class methodsFor: 'loading' stamp: 'dkh 11/12/2009 09:11'!
loadLatestPackages
	"self loadLatestPackages"
	
	^(self project version: '3.0.0-alpha5-baseline') load! !

!ConfigurationOfGrease class methodsFor: 'loading' stamp: 'dkh 11/12/2009 09:11'!
loadLatestVersion
	"self loadLatestVersion"
	
	^self project latestVersion load! !

!ConfigurationOfGrease class methodsFor: 'metacello tool support' stamp: 'dkh 11/13/2009 16:33'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfGrease class methodsFor: 'accessing' stamp: 'dkh 11/12/2009 09:11'!
project

	^self new project! !

!ConfigurationOfGrease methodsFor: 'baselines' stamp: 'dkh 11/12/2009 09:56'!
baseline10alpha1: spec 
	<version: '1.0-alpha1-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/Seaside30'.
		spec
			package: 'Grease-Core';
			package: 'Grease-Tests-Core' 
				with: [ spec requires: #('Grease-Core' ). ];
			yourself. ].

	spec for: #squeakCommon do: [
		spec
			package: 'Grease-Core' 
				with: [ spec includes: #('Grease-Pharo-Core' ) ];
			package: 'Grease-Tests-Core' 
				with: [ spec includes: #('Grease-Tests-Pharo-Core' ). ];
			package: 'Grease-Pharo-Core' 
				with: [ spec requires: #('Grease-Core' ) ];
			package: 'Grease-Tests-Pharo-Core' 
				with: [ spec requires: #('Grease-Tests-Core') ];					
			yourself. ].
	spec for: #gemstone do: [
		spec 
			repository: 'http://seaside.gemstone.com/ss/Seaside30'.

		spec 
			project: 'UTF8' with: [
				spec
					className: 'ConfigurationOfGsMisc';
					versionString: '0.233';
					loads: #('Utf8Encoding' );
					projectPackage: [
						spec
							name: 'ConfigurationOfGsMisc';
							repository: 'http://seaside.gemstone.com/ss/GLASSproject' ]];
			project: 'System-Digital-Signatures'
				copyFrom: 'UTF8'
				with: [ spec loads: #('System-Digital-Signatures' ) ];
			yourself.

		spec
			package: 'Grease-Core' 
				with: [ spec includes: #('Grease-GemStone-Core' ) ];
			package: 'Grease-Tests-Core' 
				with: [ spec includes: #('Grease-Tests-GemStone-Core' ). ];
			package: 'Grease-GemStone-Core' 
				with: [ spec requires: #('Grease-Core' 'System-Digital-Signatures' 'UTF8' ) ];
			package: 'Grease-Tests-GemStone-Core' 
				with: [ spec requires: #('Grease-Tests-Core' ) ];
			yourself. ].! !

!ConfigurationOfGrease methodsFor: 'baselines' stamp: 'dkh 11/23/2009 15:11'!
baseline10alpha2: spec 
	<version: '1.0-alpha2-baseline' imports: #('1.0-alpha1-baseline' )>

	spec for: #gemstone do: [
		spec
			project: 'SMTPMail'
				copyFrom: 'UTF8'
				with: [ spec loads: #('SMTPMail' ) ];			
			yourself.
		spec 
			package: 'Grease-GemStone-Core' 
				with: [ spec requires: #('SMTPMail' ) ];
			yourself. ].
	spec for: #'gs2.3.x' do: [
		spec 
			package: 'Grease-GemStone-Core' 
				with: [ spec includes: #('Grease-GemStone230-Core' ) ];
			package: 'Grease-GemStone230-Core' 
				with: [ spec requires: #('Grease-GemStone-Core' ) ];
			yourself. ].! !

!ConfigurationOfGrease methodsFor: 'accessing' stamp: 'dkh 11/12/2009 09:11'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear ]! !

!ConfigurationOfGrease methodsFor: 'versions' stamp: 'dkh 11/13/2009 10:41'!
version10alpha1: spec
	<version: '1.0-alpha1' imports: #('1.0-alpha1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'alpha'.
		spec author: 'dkh'.
		spec timestamp: '11/12/2009 09:41'.
		spec 
			package: 'Grease-Core' with: 'Grease-Core-obi.3';
			package: 'Grease-Tests-Core' with: 'Grease-Tests-Core-jf.1'.].
	spec for: #'squeakCommon' do: [
		spec 
			package: 'Grease-Pharo-Core' with: 'Grease-Pharo-Core-jf.1';
			package: 'Grease-Tests-Pharo-Core' with: 'Grease-Tests-Pharo-Core-jf.1'.].
	spec for: #'gemstone' do: [
		spec
			project: 'UTF8' with: '0.233';
			project: 'System-Digital-Signatures' with: '0.233'.
		spec 
			package: 'Grease-GemStone-Core' with: 'Grease-GemStone-Core-dkh.5';
			package: 'Grease-Tests-GemStone-Core' with: 'Grease-Tests-GemStone-Core-dkh.3'.].! !

!ConfigurationOfGrease methodsFor: 'versions' stamp: 'dkh 11/24/2009 10:28'!
version10alpha2: spec
	<version: '1.0-alpha2' imports: #('1.0-alpha2-baseline' )>

	spec for: #common do: [
		spec blessing: #development.
		spec description: '- in GemStone the block arg for #on:do: must always have an argument
- fix Issue 480: http://code.google.com/p/seaside/issues/detail?id=480 (GemStone/Pharo)
- fix Issue 488: http://code.google.com/p/seaside/issues/detail?id=488
- fix Issue 499: http://code.google.com/p/seaside/issues/detail?id=499 (GemStone/Pharo)
- support for loading Grease into a 2.3 GemStone/S repository
- support ''UTF-8'' has a codec name as well
- pick up latest repository changes as of 11/17/2009 15:09"
'.
		spec author: 'dkh'.
		spec timestamp: '11/23/2009 16:09'.
		spec 
			package: 'Grease-Core' with: 'Grease-Core-dkh.8';
			package: 'Grease-Tests-Core' with: 'Grease-Tests-Core-pmm.5'.].
	spec for: #squeakCommon do: [
		spec 
			package: 'Grease-Pharo-Core' with: 'Grease-Pharo-Core-dkh.3';
			package: 'Grease-Tests-Pharo-Core' with: 'Grease-Tests-Pharo-Core-dkh.2'.].
	spec for: #gemstone do: [
		spec 
			project: 'SMTPMail' with: '0.233';
			project: 'UTF8' with: '0.233';
			project: 'System-Digital-Signatures' with: '0.233'.
		spec 
			package: 'Grease-GemStone-Core' with: 'Grease-GemStone-Core-dkh.9';
			package: 'Grease-Tests-GemStone-Core' with: 'Grease-Tests-GemStone-Core-dkh.5'.].
	spec for: #'gs2.3.x' do: [
		spec package: 'Grease-GemStone230-Core' with: 'Grease-GemStone230-Core-dkh.2'.].! !
